.. _acknowledgments:

==================================
Acknowledgments and citations
==================================

Acknowledgments
-----------------
`phydms`_ is written by the `Bloom lab`_ (see the `full list of contributors`_).

Citations
------------
The current citation for `phydms`_ is `Hilton, Doud, and Bloom, PeerJ, 2017`_. **Please cite this paper if you use phydms!**

The following references are also relevant to the *ExpCM* implemented by `phydms`_:

    * `Bloom, Biology Direct, 12:1`_

    * `Bloom, Mol Biol Evol, 31:1956-1978`_

    * `Bloom, Mol Biol Evol, 31:2753-2769`_

If you use any of the simulation capabilities of `phydms`_, please also cite `pyvolve`_:

    * `Spielman and Wilke, PLoS One, 10:e0139047`_

If you use ``phydms_logoplot`` to create logo plots, please also cite `weblogo`_:

    * `Crooks et al, Genome Research, 14:1188-1190`_

Finally, if you use `dms_tools2`_ to process your deep mutational scanning data before feeding it into `phydms`_, please cite:

    * `Bloom, BMC Bioinformatics, 16:168`_



.. include:: weblinks.txt
